@@ -159,7 +159,7 @@ public:
                 return text;
             }
         }
-        return QString();
+        return {};
     }
 };
 
@@ -430,6 +430,8 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
     SemanticHighlighter m_semHighlightingManager;
     InlayHintsManager m_inlayHintsHandler;
 
+    QMetaObject::Connection m_formatOnSaveConnection;
+
     class LSPDiagnosticProvider : public DiagnosticsProvider
     {
     public:
@@ -991,7 +993,7 @@ public:
             if (!searchAttr) {
                 searchAttr = new KTextEditor::Attribute();
                 const auto theme = KTextEditor::Editor::instance()->theme();
-                QColor rangeColor = theme.editorColor(KSyntaxHighlighting::Theme::SearchHighlight);
+                QColor rangeColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::SearchHighlight));
                 searchAttr->setBackground(rangeColor);
                 searchAttr->setForeground(QBrush(theme.textColor(KSyntaxHighlighting::Theme::Normal)));
             }
@@ -1194,7 +1196,7 @@ public:
     struct RangeItem {
         QUrl uri;
         LSPRange range;
-        LSPDocumentHighlightKind kind;
+        LSPDocumentHighlightKind kind = LSPDocumentHighlightKind::Text;
 
         bool isValid() const
         {
@@ -1240,7 +1242,7 @@ public:
                     auto url = child->data(RangeData::FileUrlRole).toUrl();
                     doc = findDocument(m_mainWindow, url);
                     if (!doc) {
-                        fr.reset(new FileLineReader(url));
+                        fr = std::make_unique<FileLineReader>(url);
                     }
                 }
                 auto lineno = child->data(RangeData::RangeRole).value<LSPRange>().start().line();
@@ -1437,7 +1439,7 @@ public:
             KTextEditor::Cursor cursor = activeView->cursorPosition();
             return activeView->document()->wordAt(cursor);
         } else {
-            return QString();
+            return {};
         }
     }
 
@@ -1475,7 +1477,7 @@ public:
                 }
                 // ... so we can sort it also
                 std::stable_sort(ranges.begin(), ranges.end(), compareRangeItem);
-                makeTree(ranges, s.get()->get());
+                makeTree(ranges, s->get());
 
                 // assuming that reply ranges refer to revision when submitted
                 // (not specified anyway in protocol/reply)
@@ -1738,9 +1740,10 @@ public:
                 applyEdits(document, snapshot.get(), edits);
                 m_onTypeFormattingTriggers = savedTriggers;
                 if (save) {
-                    disconnect(document, &KTextEditor::Document::documentSavedOrUploaded, this, &self_type::formatOnSave);
+                    QObject::disconnect(m_formatOnSaveConnection);
                     document->documentSave();
-                    connect(document, &KTextEditor::Document::documentSavedOrUploaded, this, &self_type::formatOnSave);
+                    m_formatOnSaveConnection =
+                        connect(document, &KTextEditor::Document::documentSavedOrUploaded, this, &self_type::formatOnSave, Qt::QueuedConnection);
                 }
             }
         };
@@ -1898,8 +1901,9 @@ public:
     {
         KTextEditor::View *activeView = m_mainWindow->activeView();
         auto server = m_serverManager->findServer(activeView);
-        if (!server)
+        if (!server) {
             return;
+        }
 
         auto h = [this](const QString &reply) {
             auto view = m_mainWindow->openUrl(QUrl());
@@ -2201,6 +2205,7 @@ public:
         bool isClangd = false;
         bool isRustAnalyzer = false;
         bool formatOnSave = false;
+        QObject::disconnect(m_formatOnSaveConnection);
 
         if (server) {
             const auto &caps = server->capabilities();
@@ -2334,8 +2339,8 @@ public:
         updateMarks(doc);
 
         if (formatOnSave) {
-            auto t = Qt::ConnectionType(Qt::UniqueConnection | Qt::QueuedConnection);
-            connect(activeView->document(), &KTextEditor::Document::documentSavedOrUploaded, this, &self_type::formatOnSave, t);
+            m_formatOnSaveConnection =
+                connect(activeView->document(), &KTextEditor::Document::documentSavedOrUploaded, this, &self_type::formatOnSave, Qt::QueuedConnection);
         }
 
         // connect for cleanup stuff
