@@ -176,7 +176,7 @@ static const rapidjson::Value &GetJsonArrayForKey(const rapidjson::Value &v, std
 
 static QJsonValue encodeUrl(const QUrl &url)
 {
-    return QJsonValue(QLatin1String(urlTransform(url, true).toEncoded()));
+    return QJsonValue(QString::fromUtf8(urlTransform(url, true).toEncoded()));
 }
 
 // message construction helpers
@@ -195,7 +195,7 @@ static QJsonValue to_json(const LSPLocation &location)
     if (location.uri.isValid()) {
         return QJsonObject{{QLatin1String(MEMBER_URI), encodeUrl(location.uri)}, {QLatin1String(MEMBER_RANGE), to_json(location.range)}};
     }
-    return QJsonValue();
+    return {};
 }
 
 static QJsonValue to_json(const LSPDiagnosticRelatedInformation &related)
@@ -204,7 +204,7 @@ static QJsonValue to_json(const LSPDiagnosticRelatedInformation &related)
     if (loc.isObject()) {
         return QJsonObject{{QLatin1String(MEMBER_LOCATION), to_json(related.location)}, {QLatin1String(MEMBER_MESSAGE), related.message}};
     }
-    return QJsonValue();
+    return {};
 }
 
 static QJsonObject to_json(const LSPDiagnostic &diagnostic)
@@ -967,10 +967,10 @@ static LSPSignatureHelp parseSignatureHelp(const rapidjson::Value &result)
     }
     ret.activeSignature = GetIntValue(result, "activeSignature", 0);
     ret.activeParameter = GetIntValue(result, "activeParameter", 0);
-    ret.activeSignature = qMin(qMax(ret.activeSignature, 0), ret.signatures.size());
-    ret.activeParameter = qMax(ret.activeParameter, 0);
+    ret.activeSignature = std::min(std::max(ret.activeSignature, 0), static_cast<int>(ret.signatures.size()));
+    ret.activeParameter = std::max(ret.activeParameter, 0);
     if (!ret.signatures.isEmpty()) {
-        ret.activeParameter = qMin(ret.activeParameter, ret.signatures.at(ret.activeSignature).parameters.size());
+        ret.activeParameter = std::min(ret.activeParameter, static_cast<int>(ret.signatures.at(ret.activeSignature).parameters.size()));
     }
     return ret;
 }
@@ -1455,8 +1455,9 @@ public:
     QUrl mapPath(const QUrl &url, bool fromLocal) const
     {
         auto &m = m_config.map;
-        if (!m || m->isEmpty())
+        if (!m || m->isEmpty()) {
             return url;
+        }
         auto result = Utils::mapPath(*m, url, fromLocal);
         qCDebug(LSPCLIENT) << "transform url" << fromLocal << url << "->" << result;
         // use special scheme to mark unmappable remote file
@@ -1528,7 +1529,7 @@ private:
         } else {
             qCWarning(LSPCLIENT, "send for non-running server");
         }
-        return RequestHandle();
+        return {};
     }
 
     void readStandardOutput()
@@ -1816,7 +1817,7 @@ private:
         auto root = mapPath(m_root, true);
         QJsonObject params{{QStringLiteral("processId"), QCoreApplication::applicationPid()},
                            {QStringLiteral("rootPath"), root.isValid() ? root.toLocalFile() : QJsonValue()},
-                           {QStringLiteral("rootUri"), root.isValid() ? root.toString() : QJsonValue()},
+                           {QStringLiteral("rootUri"), root.isValid() ? QJsonValue(QString::fromUtf8(root.toEncoded())) : QJsonValue()},
                            {QStringLiteral("capabilities"), capabilities},
                            {QStringLiteral("initializationOptions"), m_init}};
         // only add new style workspaces init if so specified
@@ -2069,7 +2070,7 @@ public:
         PushCurrentServer g(q);
         auto params = executeCommandParams(command);
         // Pass an empty lambda as reply handler because executeCommand is a Request, but we ignore the result
-        send(init_request(QStringLiteral("workspace/executeCommand"), params), [](const auto &) {});
+        send(init_request(QStringLiteral("workspace/executeCommand"), params), [](const auto &) { });
     }
 
     void didOpen(const QUrl &document, int version, const QString &langId, const QString &text)
