@@ -265,7 +265,7 @@ public Q_SLOTS:
 
 private:
     QString m_filterString;
-    FilterMode m_filterMode;
+    FilterMode m_filterMode = FilterMode::Fuzzy;
 };
 
 KateQuickOpen::KateQuickOpen(KateMainWindow *mainWindow)
@@ -306,8 +306,8 @@ KateQuickOpen::KateQuickOpen(KateMainWindow *mainWindow)
         if (didFilter) {
             m_styleDelegate->setFilterString(text);
             m_listView->viewport()->update();
-            reselectFirst();
         }
+        reselectFirst();
     });
 
     setHidden(true);
@@ -408,50 +408,55 @@ void KateQuickOpen::slotReturnPressed()
 
     // either get view via document pointer or url
     const QModelIndex index = m_listView->currentIndex();
-    KTextEditor::View *view = nullptr;
-    if (auto *doc = index.data(KateQuickOpenModel::Document).value<KTextEditor::Document *>()) {
-        view = m_mainWindow->activateView(doc);
-    } else {
-        QFileInfo file(index.data(Qt::UserRole).toUrl().toLocalFile());
-        // If the file is a directory, we're likely opening a project
-        if (file.isDir()) {
-            // Make sure projectview exists, then invoke switchToProject method with the directory we have
-            QObject *projectView = m_mainWindow->pluginView(QStringLiteral("kateprojectplugin"));
-            if (projectView) {
-                QMetaObject::invokeMethod(projectView, "switchToProject", Qt::DirectConnection, QDir(index.data(Qt::UserRole).toUrl().toLocalFile()));
-                QWidget *toolview = m_mainWindow->toolviewForName(QStringLiteral("kate_mdi_focus_toolview_projects"));
-                if (toolview) {
-                    m_mainWindow->showToolView(toolview);
-                    toolview->setFocus();
-                }
-            }
-        } else {
-            view = m_mainWindow->wrapper()->openUrl(index.data(Qt::UserRole).toUrl());
+    KTextEditor::View *view = [index, this]() -> KTextEditor::View * {
+        if (!index.isValid()) {
+            return nullptr;
         }
-    }
+        if (auto *doc = index.data(KateQuickOpenModel::Document).value<KTextEditor::Document *>()) {
+            return m_mainWindow->activateView(doc);
+        } else {
+            QFileInfo file(index.data(Qt::UserRole).toUrl().toLocalFile());
+            // If the file is a directory, we're likely opening a project
+            if (file.isDir()) {
+                // Make sure projectview exists, then invoke switchToProject method with the directory we have
+                QObject *projectView = m_mainWindow->pluginView(QStringLiteral("kateprojectplugin"));
+                if (projectView) {
+                    QMetaObject::invokeMethod(projectView, "switchToProject", Qt::DirectConnection, QDir(index.data(Qt::UserRole).toUrl().toLocalFile()));
+                    QWidget *toolview = m_mainWindow->toolviewForName(QStringLiteral("kate_mdi_focus_toolview_projects"));
+                    if (toolview) {
+                        m_mainWindow->showToolView(toolview);
+                        toolview->setFocus();
+                    }
+                }
+            } else {
+                return m_mainWindow->wrapper()->openUrl(index.data(Qt::UserRole).toUrl());
+            }
+        }
+        return nullptr;
+    }();
 
     const QStringList strs = m_inputLine->text().split(QLatin1Char(':'));
     if (view && strs.count() > 1) {
-        // helper to convert String => Number
-        std::function<int(const QString &)> stringToInt = [](const QString &s) {
-            bool ok = false;
-            const int num = s.toInt(&ok);
-            return ok ? num : -1;
-        };
-        KTextEditor::Cursor cursor = KTextEditor::Cursor::invalid();
+        // convert strings to cursor
+        const auto cursor = [](const QStringList &strs) -> KTextEditor::Cursor {
+            if (strs.size() > 1) {
+                bool ok = false;
+                int line = strs.at(1).toInt(&ok);
+                if (ok) {
+                    if (strs.size() > 2) {
+                        int column = strs.at(2).toInt(&ok);
+                        if (ok) {
+                            return {line - 1, column - 1};
+                        }
+                    }
+                    return {line - 1, 0};
+                }
+            }
+            return KTextEditor::Cursor::invalid();
+        }(strs);
 
-        // try to get line
-        const int line = stringToInt(strs.at(1));
-        cursor.setLine(line - 1);
-
-        // if line is valid, try to see if we have column available as well
-        if (line > -1 && strs.count() > 2) {
-            const int col = stringToInt(strs.at(2));
-            cursor.setColumn(col - 1);
-        }
-
-        // do we have valid line at least?
-        if (line > -1) {
+        // jump to position if we have a valid cursor
+        if (cursor.isValid()) {
             view->setCursorPosition(cursor);
         }
     }
